"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.FileUploadStatus = exports.FileUploadPreview = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _q3UiHelpers = require("q3-ui-helpers");

var _lodash = require("lodash");

var _q3UiLocale = require("q3-ui-locale");

var _IconButton = _interopRequireDefault(require("@material-ui/core/IconButton"));

var _PhotoCamera = _interopRequireDefault(require("@material-ui/icons/PhotoCamera"));

var _Box = _interopRequireDefault(require("@material-ui/core/Box"));

var _RemoveCircle = _interopRequireDefault(require("@material-ui/icons/RemoveCircle"));

var _BrokenImage = _interopRequireDefault(require("@material-ui/icons/BrokenImage"));

var _Drop = _interopRequireDefault(require("../Drop"));

var _useStyle = _interopRequireDefault(require("./useStyle"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const FileUploadPreview = ({
  src
}) => {
  const {
    t
  } = (0, _q3UiLocale.useTranslation)('labels');

  const [error, setError] = _react.default.useState(false);

  const cls = (0, _useStyle.default)();
  return /*#__PURE__*/_react.default.createElement(_Box.default, {
    className: cls.previewContainer
  }, src && !error ? /*#__PURE__*/_react.default.createElement("img", {
    alt: t('imageThumbnailPreview'),
    className: cls.fit,
    src: src,
    onError: () => {
      setError('true');
    }
  }) : /*#__PURE__*/_react.default.createElement(_Box.default, {
    className: cls.icon
  }, error ? /*#__PURE__*/_react.default.createElement(_BrokenImage.default, null) : /*#__PURE__*/_react.default.createElement(_PhotoCamera.default, null)));
};

exports.FileUploadPreview = FileUploadPreview;
FileUploadPreview.defaultProps = {
  src: ''
};
FileUploadPreview.propTypes = {
  src: _propTypes.default.string
};

const FileUploadStatus = ({
  file,
  onDelete
}) => {
  const {
    t
  } = (0, _q3UiLocale.useTranslation)('labels');
  const cls = (0, _useStyle.default)();

  _react.default.useEffect(() => {
    // eslint-disable-next-line
    if (file !== null && file !== void 0 && file.error) alert(t('photoFailedToUpload'));
  }, [file === null || file === void 0 ? void 0 : file.error]);

  if (file !== null && file !== void 0 && file.url && (0, _lodash.isFunction)(onDelete)) return /*#__PURE__*/_react.default.createElement(_IconButton.default, {
    id: "q3-photo-remove",
    type: "button",
    onClick: onDelete,
    className: cls.danger,
    "aria-label": t('unsetPhoto'),
    fullWidth: true
  }, /*#__PURE__*/_react.default.createElement(_RemoveCircle.default, null));
  return null;
};

exports.FileUploadStatus = FileUploadStatus;
FileUploadStatus.defaultProps = {
  file: null
};
FileUploadStatus.propTypes = {
  file: _propTypes.default.shape({
    url: _propTypes.default.string,
    error: _propTypes.default.bool
  }),
  onDelete: _propTypes.default.func.isRequired
};

const PhotoUpload = ({
  src,
  onDelete,
  ...etc
}) => {
  const [previewUrl, setPreviewUrl] = _react.default.useState();

  _react.default.useEffect(() => {
    setPreviewUrl(src);
  }, [src]);

  return /*#__PURE__*/_react.default.createElement(_Box.default, {
    position: "relative"
  }, /*#__PURE__*/_react.default.createElement(_Drop.default, _extends({}, etc, {
    multiple: false,
    accept: ".png,.jpg,.jpeg,.svg,.jfif",
    previewComponent: /*#__PURE__*/_react.default.createElement(FileUploadPreview, {
      src: previewUrl
    })
  }), ([file]) => {
    _q3UiHelpers.browser.getFileThumbnail(file, (err, previewSrc) => {
      if (src) setPreviewUrl(previewSrc);
    }); // allows us to "fake" the existing file blob


    return /*#__PURE__*/_react.default.createElement(_Box.default, {
      position: "absolute",
      top: "0",
      right: "0"
    }, /*#__PURE__*/_react.default.createElement(FileUploadStatus, {
      file: file || {
        url: src
      },
      onDelete: onDelete
    }));
  }));
};

PhotoUpload.defaultProps = {
  src: ''
};
PhotoUpload.propTypes = {
  src: _propTypes.default.string,
  onDelete: _propTypes.default.func.isRequired
};
var _default = PhotoUpload;
exports.default = _default;